\name{createMergedAdjacencyMatrix}
\alias{createMergedAdjacencyMatrix}
\title{Create merged adjacency matrix for multilayer network}
\description{
Generates an adjacency matrix for a single network that is formed 
by connecting together each layer in a multilayer network. Specifically,
if the off-diagonal entry for row i and column j in the inter-layer dependency matrix \code{A} is
not zero, then a directed edge is added with the weight of that entry between all nodes in
layer i and the same nodes in layer j.
}
\usage{
    createMergedAdjacencyMatrix(X, A)
}
\arguments{
\item{X}{List of k (k >= 2) p-by-p adjacency matrices for a multilayer network.}
\item{A}{A k-by-k matrix whose values capture the dependencies 
between the k network layers represented by \code{X}. 
The off-diagonal elements capture the dependency between each pair of layers, which is
realized by adding directed inter-layer edges. The diagonal elements are ignored.}
}
\value{
The kp-by-kp adjacency matrix for the network created by combining the networks for each of the k layers using inter-layer edges.
}
\keyword{file}
\examples{
    # Define the adjacency matrices for a 2 layer, 3 node multilayer network
    # In the first layer, node 1 is connected to nodes 2 and 3 with weight 1
    # and nodes 2 and 3 are connected with weight 0.5
    X1 = matrix(c(0,1,1,
                  1,0,0.5,
                  1,0.5,0),
            nrow=3, byrow=TRUE)
    # In the second layer, nodes 1 and 3 are connected to node 2 with 
    # weight 1 and 1 and 3 are connected with weight 0.5
    X2 = matrix(c(0,1,0.5,
                  1,0,1,
                  0.5,1,0),
            nrow=3, byrow=TRUE)
    
    # Combine both adjacency matrices into the multilayer list
    X = list(X1, X2)
    
    # Create the merged adjacency matrix without any inter-edges. Note that this
    # matrix matrix is not irreducible!
    createMergedAdjacencyMatrix(X=X, A=diag(c(1,1)))
    
    # Define a depenency matrix where layers 1 and 2 have undirected edges between their nodes
    A = matrix(c(0,1,
                 1,0),
            nrow=2, byrow=TRUE)
            
    # Create the merged adjacency matrix for this structure of inter-layer edges. This
    # matrix is irreducible.
    createMergedAdjacencyMatrix(X=X, A=A)
}
